@@ -1,8 +1,9 @@
 from __future__ import unicode_literals
-
 from decimal import Decimal
 
-VERSION = (0, 2, 2)
+default_app_config = 'geoposition.apps.GeoPositionConfig'
+
+VERSION = (0, 3, 11)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -26,7 +27,11 @@ class Geoposition(object):
         return len(str(self))
 
     def __eq__(self, other):
-        return isinstance(other, Geoposition) and self.latitude == other.latitude and self.longitude == other.longitude
+        return isinstance(
+            other, Geoposition
+        ) and self.latitude == other.latitude and self.longitude == other.longitude
 
     def __ne__(self, other):
-        return not isinstance(other, Geoposition) or self.latitude != other.latitude or self.longitude != other.longitude
+        return not isinstance(
+            other, Geoposition
+        ) or self.latitude != other.latitude or self.longitude != other.longitude
